pub struct DiagnosticBag { /* private fields */ }Expand description
Accumulates diagnostics emitted during a compilation pass.
Implementations
Sourceimpl DiagnosticBag
impl DiagnosticBag
Sourcepub fn error(
&mut self,
code: DiagnosticCode,
message: impl Into<String>,
span: Span,
) -> &mut Diagnostic
pub fn error( &mut self, code: DiagnosticCode, message: impl Into<String>, span: Span, ) -> &mut Diagnostic
Emit an error diagnostic and return a mutable reference for further decoration.
Sourcepub fn warning(
&mut self,
code: DiagnosticCode,
message: impl Into<String>,
span: Span,
) -> &mut Diagnostic
pub fn warning( &mut self, code: DiagnosticCode, message: impl Into<String>, span: Span, ) -> &mut Diagnostic
Emit a warning diagnostic and return a mutable reference for further decoration.
Sourcepub fn info(
&mut self,
code: DiagnosticCode,
message: impl Into<String>,
span: Span,
) -> &mut Diagnostic
pub fn info( &mut self, code: DiagnosticCode, message: impl Into<String>, span: Span, ) -> &mut Diagnostic
Emit an info diagnostic and return a mutable reference for further decoration.
Sourcepub fn hint(
&mut self,
code: DiagnosticCode,
message: impl Into<String>,
span: Span,
) -> &mut Diagnostic
pub fn hint( &mut self, code: DiagnosticCode, message: impl Into<String>, span: Span, ) -> &mut Diagnostic
Emit a hint diagnostic and return a mutable reference for further decoration.
Sourcepub fn has_errors(&self) -> bool
pub fn has_errors(&self) -> bool
Returns true if any error-severity diagnostics have been emitted.
Sourcepub fn error_count(&self) -> usize
pub fn error_count(&self) -> usize
Returns the number of error-severity diagnostics emitted so far.
Sourcepub fn warning_count(&self) -> usize
pub fn warning_count(&self) -> usize
Returns the number of warning-severity diagnostics emitted so far.
Sourcepub fn iter(&self) -> impl Iterator<Item = &Diagnostic>
pub fn iter(&self) -> impl Iterator<Item = &Diagnostic>
Iterate over all collected diagnostics.